from django.apps import AppConfig


class RobotMCPFrontendConfig(AppConfig):
    """App configuration for the RobotMCP Django frontend."""

    default_auto_field = "django.db.models.AutoField"
    name = "robotmcp.frontend"
    verbose_name = "RobotMCP Frontend"
